summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorHeinrich Schuchardt <[email protected]>2025-11-23 23:57:08 +0100
committerTom Rini <[email protected]>2025-12-05 08:54:44 -0600
commit3338e2e463793425c23acf859438238670a10a11 (patch)
treea0198de4826ebd8688dc75ffe7cd69ce3b559987 /test
parent6b0997c98c0e7c46e25ff3fc8a7d1142ce71bcbb (diff)
test: relax cread_test time constraint
The ppce500 is not as fine grained as expected. Signed-off-by: Heinrich Schuchardt <[email protected]>
Diffstat (limited to 'test')
-rw-r--r--test/common/cread.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/test/common/cread.c b/test/common/cread.c
index 4926c216803..5afc7397212 100644
--- a/test/common/cread.c
+++ b/test/common/cread.c
@@ -90,13 +90,14 @@ static int cread_test(struct unit_test_state *uts)
ut_asserteq(5, cli_readline_into_buffer("-> ", buf, 1));
ut_asserteq_str("abcXx", buf);
/* check timeout, should be between 1000 and 1050ms */
start = get_timer(0);
*buf = '\0';
ut_asserteq(-2, cli_readline_into_buffer("-> ", buf, 1));
- duration = get_timer(start) - 1000;
- ut_assert(duration >= 0);
- ut_assert(duration < 50);
+ printf("get_timer(start): %ld", get_timer(start));
+ duration = get_timer(start);
+ ut_assert(duration >= 900);
+ ut_assert(duration < 1100);
return 0;
}
@@ -90,13 +90,14 @@ static int cread_test(struct unit_test_state *uts)
ut_asserteq(5, cli_readline_into_buffer("-> ", buf, 1));
ut_asserteq_str("abcXx", buf);
- /* check timeout, should be between 1000 and 1050ms */
+ /* check timeout, should be between 900 and 1100ms */
start = get_timer(0);
*buf = '\0';